@@ -4,12 +4,17 @@ use warnings;
 use KinoSearch::Util::ToolSet;
 use base qw( KinoSearch::Analysis::Analyzer );
 
+BEGIN {
+    __PACKAGE__->init_instance_vars(
+        # constructor params / members
+        analyzers => undef,
+    );
+}
+
 use KinoSearch::Analysis::LCNormalizer;
 use KinoSearch::Analysis::Tokenizer;
 use KinoSearch::Analysis::Stemmer;
 
-our %instance_vars = __PACKAGE__->init_instance_vars( analyzers => undef, );
-
 sub init_instance {
     my $self     = shift;
     my $language = $self->{language} = lc( $self->{language} );
@@ -119,7 +124,7 @@ Copyright 2005-2006 Marvin Humphrey
 
 =head1 LICENSE, DISCLAIMER, BUGS, etc.
 
-See L<KinoSearch|KinoSearch> version 0.09.
+See L<KinoSearch|KinoSearch> version 0.10.
 
 =cut
 
