@@ -3,12 +3,17 @@ use strict;
 use warnings;
 use KinoSearch::Util::ToolSet;
 use base qw( KinoSearch::Analysis::Analyzer );
+
+BEGIN {
+    __PACKAGE__->init_instance_vars(
+        # constructor params / members
+        stoplist => undef,
+    );
+}
+
 use KinoSearch::Analysis::Stemmer qw( %supported_languages );
-
 use Lingua::StopWords;
 
-our %instance_vars = __PACKAGE__->init_instance_vars( stoplist => undef, );
-
 sub init_instance {
     my $self     = shift;
     my $language = $self->{language} = lc( $self->{language} );
@@ -155,7 +160,7 @@ Copyright 2005-2006 Marvin Humphrey
 
 =head1 LICENSE, DISCLAIMER, BUGS, etc.
 
-See L<KinoSearch|KinoSearch> version 0.09.
+See L<KinoSearch|KinoSearch> version 0.10.
 
 =cut
 
