@@ -3,18 +3,21 @@ use strict;
 use warnings;
 use KinoSearch::Util::ToolSet;
 use base qw( KinoSearch::Analysis::Analyzer );
+use locale;
+
+BEGIN {
+    __PACKAGE__->init_instance_vars(
+
+        # constructor params / members
+        token_re => undef,    # regex for a single token
+
+        # members
+        separator_re => undef,    # regex for separations between tokens
+    );
+}
 
 use KinoSearch::Analysis::TokenBatch;
 
-our %instance_vars = __PACKAGE__->init_instance_vars(
-
-    # constructor params / members
-    token_re => undef,    # regex for a single token
-
-    # members
-    separator_re => undef,    # regex for separations between tokens
-);
-
 sub init_instance {
     my $self = shift;
 
@@ -147,6 +150,6 @@ Copyright 2005-2006 Marvin Humphrey
 
 =head1 LICENSE, DISCLAIMER, BUGS, etc.
 
-See L<KinoSearch|KinoSearch> version 0.09.
+See L<KinoSearch|KinoSearch> version 0.10.
 
 =cut
