@@ -4,16 +4,18 @@ use warnings;
 use KinoSearch::Util::ToolSet;
 use base qw( KinoSearch::Store::InvIndex );    # !!
 
-use KinoSearch::Store::InStream;
+BEGIN {
+    __PACKAGE__->init_instance_vars(
+        # members / constructor params
+        invindex => undef,
+        seg_name => undef,
+        # members
+        instream => undef,
+        entries  => undef,
+    );
+}
 
-our %instance_vars = __PACKAGE__->init_instance_vars(
-    # members / constructor params
-    invindex => undef,
-    seg_name => undef,
-    # members
-    instream => undef,
-    entries  => undef,
-);
+use KinoSearch::Store::InStream;
 
 sub init_instance {
     my $self = shift;
@@ -57,6 +59,8 @@ sub slurp_file {
     return $contents;
 }
 
+sub close { shift->{instream}->close }
+
 1;
 
 __END__
@@ -93,7 +97,7 @@ Copyright 2005-2006 Marvin Humphrey
 
 =head1 LICENSE, DISCLAIMER, BUGS, etc.
 
-See L<KinoSearch|KinoSearch> version 0.08.
+See L<KinoSearch|KinoSearch> version 0.10.
 
 =end devdocs
 =cut
