@@ -4,14 +4,16 @@ use warnings;
 use KinoSearch::Util::ToolSet;
 use base qw( KinoSearch::Util::Class );
 
-our %instance_vars = __PACKAGE__->init_instance_vars(
-    # constructor params / members
-    invindex => undef,
-    filename => undef,
-    # members
-    entries => {},
-    merged  => 0,
-);
+BEGIN {
+    __PACKAGE__->init_instance_vars(
+        # constructor params / members
+        invindex => undef,
+        filename => undef,
+        # members
+        entries => {},
+        merged  => 0,
+    );
+}
 
 # Add a file to the list of files-to-merge.
 sub add_file {
@@ -80,7 +82,7 @@ Copyright 2005-2006 Marvin Humphrey
 
 =head1 LICENSE, DISCLAIMER, BUGS, etc.
 
-See L<KinoSearch|KinoSearch> version 0.08.
+See L<KinoSearch|KinoSearch> version 0.10.
 
 =end devdocs
 =cut
