@@ -4,11 +4,21 @@ use warnings;
 use KinoSearch::Util::ToolSet;
 use base qw( KinoSearch::Util::Class Exporter );
 
-use KinoSearch::Document::Field;
+use constant INDEXED    => "\x01";
+use constant VECTORIZED => "\x02";
+use constant OMIT_NORMS => "\x10";
 
 our @EXPORT_OK;
 
 BEGIN {
+    __PACKAGE__->init_instance_vars(
+        # members
+        by_name   => {},
+        by_num    => [],
+        from_file => 0,
+    );
+    __PACKAGE__->ready_get_set(qw( from_file ));
+
     @EXPORT_OK = qw(
         INDEXED
         VECTORIZED
@@ -16,35 +26,21 @@ BEGIN {
     );
 }
 
-use constant INDEXED    => "\x01";
-use constant VECTORIZED => "\x02";
-use constant OMIT_NORMS => "\x10";
-
+use KinoSearch::Document::Field;
 use Clone qw( clone );
 
-our %instance_vars = __PACKAGE__->init_instance_vars(
-    # members
-    by_name   => {},
-    by_num    => [],
-    from_file => 0,
-);
-
 # Add a user-supplied Field object to the collection.
 sub add_field {
     my ( $self, $field ) = @_;
+    croak("Not a KinoSearch::Document::Field")
+        unless a_isa_b( $field, 'KinoSearch::Document::Field' );
 
     # don't mod Field objects for segments that are read back in
     croak("Can't update FieldInfos that were read in from file")
         if $self->{from_file};
 
-    # misc verifications
-    croak("Not a KinoSearch::Document::Field")
-        unless a_isa_b( $field, 'KinoSearch::Document::Field' );
-    my $fieldname = $field->get_name;
-    croak("Field '$fieldname' already defined")
-        if exists $self->{by_name}{$fieldname};
-
     # add the field
+    my $fieldname = $field->get_name;
     $self->{by_name}{$fieldname} = $field;
     $self->_assign_field_nums;
 }
@@ -58,7 +54,7 @@ sub get_infos { @{ $_[0]->{by_num} } }
 # Given a fieldname, return its number.
 sub get_field_num {
     my ( $self, $name ) = @_;
-    confess("don't have a field_num for field named '$name'")
+    return undef
         unless exists $self->{by_name}{$name};
     my $num = $self->{by_name}{$name}->get_field_num;
     return $num;
@@ -148,14 +144,18 @@ sub consolidate {
     }
 
     $self->_assign_field_nums;
+}
 
-    # sync field nums in all the others with the master
-    #    for my $other (@others) {
-    #        for my $other_finfo ( @{ $other->{by_num} } ) {
-    #            $other_finfo->{field_num}
-    #                = $infos->{"$other_finfo->{name}"}{field_num};
-    #        }
-    #    }
+# Generate a mapping of field numbers between two FieldInfos objects.  Should
+# be called by the superset.
+sub generate_field_num_map {
+    my ( $self, $other ) = @_;
+    my $map = '';
+    for my $other_finfo ( @{ $other->{by_num} } ) {
+        my $orig_finfo = $self->{by_name}{ $other_finfo->get_name };
+        $map .= pack( 'I', $orig_finfo->get_field_num );
+    }
+    return KinoSearch::Util::IntMap->new( \$map );
 }
 
 sub encode_fnm_bits {
@@ -176,6 +176,8 @@ sub decode_fnm_bits {
     $field->set_omit_norms( ( $bits & OMIT_NORMS ) eq OMIT_NORMS );
 }
 
+sub close { }
+
 1;
 
 __END__
@@ -206,7 +208,7 @@ Copyright 2005-2006 Marvin Humphrey
 
 =head1 LICENSE, DISCLAIMER, BUGS, etc.
 
-See L<KinoSearch|KinoSearch> version 0.08.
+See L<KinoSearch|KinoSearch> version 0.10.
 
 =end devdocs
 =cut
