@@ -4,27 +4,29 @@ use warnings;
 use KinoSearch::Util::ToolSet;
 use base qw( KinoSearch::Util::Class Exporter );
 
-our @EXPORT_OK;
-
-BEGIN { @EXPORT_OK = qw( ANALYZED BINARY COMPRESSED ) }
-
 use constant ANALYZED   => "\x01";
 use constant BINARY     => "\x02";
 use constant COMPRESSED => "\x04";
 
+our @EXPORT_OK;
+
+BEGIN {
+    @EXPORT_OK = qw( ANALYZED BINARY COMPRESSED );
+    __PACKAGE__->init_instance_vars(
+        # constructor params / members
+        finfos        => undef,
+        fdata_stream  => undef,
+        findex_stream => undef,
+        # members
+        size => undef,
+    );
+
+}
+
 use Compress::Zlib qw( uncompress );
 use KinoSearch::Document::Field;
 use KinoSearch::Document::Doc;
 
-our %instance_vars = __PACKAGE__->init_instance_vars(
-    # constructor params / members
-    finfos        => undef,
-    fdata_stream  => undef,
-    findex_stream => undef,
-    # members
-    size => undef,
-);
-
 sub init_instance {
     my $self = shift;
 
@@ -140,7 +142,7 @@ Copyright 2005-2006 Marvin Humphrey
 
 =head1 LICENSE, DISCLAIMER, BUGS, etc.
 
-See L<KinoSearch|KinoSearch> version 0.09.
+See L<KinoSearch|KinoSearch> version 0.10.
 
 =end devdocs
 =cut
