@@ -4,18 +4,20 @@ use warnings;
 use KinoSearch::Util::ToolSet;
 use base qw( KinoSearch::Index::IndexReader );
 
+BEGIN {
+    __PACKAGE__->init_instance_vars(
+        invindex    => undef,
+        sub_readers => [],
+        starts      => [],
+        max_doc     => 0,
+        norms_cache => {},
+    );
+}
+
 use KinoSearch::Index::FieldInfos;
 use KinoSearch::Index::SegReader;
 use KinoSearch::Index::MultiTermDocs;
 
-our %instance_vars = __PACKAGE__->init_instance_vars(
-    invindex    => undef,
-    sub_readers => [],
-    starts      => [],
-    max_doc     => 0,
-    norms_cache => {},
-);
-
 # use KinoSearch::Util::Class's new()
 # Note: can't inherit IndexReader's new() without recursion problems
 *new = *KinoSearch::Util::Class::new;
@@ -189,6 +191,12 @@ sub fibonacci {
     return $result;
 }
 
+sub close {
+    my $self = shift;
+    return unless $self->{close_invindex};
+    $_->close for @{ $self->{sub_readers} };
+}
+
 1;
 
 __END__
@@ -209,7 +217,7 @@ Copyright 2005-2006 Marvin Humphrey
 
 =head1 LICENSE, DISCLAIMER, BUGS, etc.
 
-See L<KinoSearch|KinoSearch> version 0.09.
+See L<KinoSearch|KinoSearch> version 0.10.
 
 =end devdocs
 =cut
