@@ -4,14 +4,17 @@ use warnings;
 use KinoSearch::Util::ToolSet;
 use base qw( KinoSearch::Index::TermDocs );
 
-our %instance_vars = __PACKAGE__->init_instance_vars(
-    sub_readers => [],
-    starts      => [],
-);
+BEGIN {
+    __PACKAGE__->init_instance_vars(
+        sub_readers => [],
+        starts      => [],
+    );
+}
+our %instance_vars;
 
 sub new {
     my $self = shift->SUPER::new;
-    verify_args( \%instance_vars, @_ );
+    confess kerror() unless verify_args( \%instance_vars, @_ );
     my %args = ( %instance_vars, @_ );
 
     # get a SegTermDocs for each segment
@@ -77,23 +80,18 @@ _set_or_get(term_docs, ...)
 ALIAS:
     _set_sub_term_docs = 1
     _get_sub_term_docs = 2
-PREINIT:
-    MultiTermDocsChild *child;
 CODE:
 {
-    child = (MultiTermDocsChild*)term_docs->child;
+    MultiTermDocsChild *child = (MultiTermDocsChild*)term_docs->child;
 
-    /* if called as a setter, make sure the extra arg is there */
-    if (ix % 2 == 1 && items != 2)
-        Kino_confess("usage: $term_docs->set_xxxxxx($val)");
-
-    switch (ix) {
+    KINO_START_SET_OR_GET_SWITCH
         
     case 1:  Kino_confess("Can't set sub_term_docs");
              /* fall through */
     case 2:  RETVAL = newSVsv( child->sub_term_docs_avref );
              break;
-    }
+
+    KINO_END_SET_OR_GET_SWITCH
 }
 OUTPUT: RETVAL
 
@@ -110,7 +108,7 @@ __H__
 #include "KinoSearchUtilMemManager.h"
 
 typedef struct multitermdocschild {
-    U32        num_subs;
+    I32        num_subs;
     I32        base;
     I32        pointer;
     SV        *sub_term_docs_avref;
@@ -126,7 +124,7 @@ U32  Kino_MultiTermDocs_get_doc_freq(TermDocs*);
 U32  Kino_MultiTermDocs_get_doc(TermDocs*);
 U32  Kino_MultiTermDocs_get_freq(TermDocs*);
 SV*  Kino_MultiTermDocs_get_positions(TermDocs*);
-U32  Kino_MultiTermDocs_read(TermDocs*, SV*, SV*, U32);
+U32  Kino_MultiTermDocs_bulk_read(TermDocs*, SV*, SV*, U32);
 bool Kino_MultiTermDocs_next(TermDocs*);
 void Kino_MultiTermDocs_destroy(TermDocs*);
 
@@ -140,9 +138,9 @@ void
 Kino_MultiTermDocs_init_child(TermDocs* term_docs, SV *sub_term_docs_avref, 
                               AV *starts_av) {
     MultiTermDocsChild *child;
-    int                 i;
+    I32                 i;
     SV                **sv_ptr;
-	AV                 *sub_term_docs_av;
+    AV                 *sub_term_docs_av;
 
     /* allocate */
     Kino_New(0, child, 1, MultiTermDocsChild);
@@ -155,7 +153,7 @@ Kino_MultiTermDocs_init_child(TermDocs* term_docs, SV *sub_term_docs_avref,
 
     /* extract AV* and take stock of how many sub-TermDocs we've got */
     child->sub_term_docs_avref = newSVsv(sub_term_docs_avref);;
-	sub_term_docs_av = (AV*)SvRV(sub_term_docs_avref);
+    sub_term_docs_av = (AV*)SvRV(sub_term_docs_avref);
     child->num_subs = av_len(sub_term_docs_av) + 1;
 
     /* extract starts from starts array, subTermDocs from the subs array */
@@ -179,9 +177,9 @@ Kino_MultiTermDocs_init_child(TermDocs* term_docs, SV *sub_term_docs_avref,
     term_docs->get_doc       = Kino_MultiTermDocs_get_doc;
     term_docs->get_freq      = Kino_MultiTermDocs_get_freq;
     term_docs->get_positions = Kino_MultiTermDocs_get_positions;
-    term_docs->read          = Kino_MultiTermDocs_read;
+    term_docs->bulk_read     = Kino_MultiTermDocs_bulk_read;
     term_docs->next          = Kino_MultiTermDocs_next;
-	term_docs->destroy       = Kino_MultiTermDocs_destroy;
+    term_docs->destroy       = Kino_MultiTermDocs_destroy;
 }
 
 void
@@ -193,10 +191,10 @@ U32
 Kino_MultiTermDocs_get_doc_freq(TermDocs *term_docs) {
     MultiTermDocsChild *child;
     TermDocs           *sub_td;
-    int                 i;
+    I32                 i;
     U32                 doc_freq = 0;
 
-	/* sum the doc_freqs of all segments */
+    /* sum the doc_freqs of all segments */
     child = (MultiTermDocsChild*)term_docs->child;
     for (i = 0; i < child->num_subs; i++) {
         sub_td = child->sub_term_docs[i];
@@ -240,8 +238,8 @@ Kino_MultiTermDocs_get_positions(TermDocs *term_docs) {
 
 
 U32
-Kino_MultiTermDocs_read(TermDocs *term_docs, SV *doc_nums_sv, SV *freqs_sv,
-                        U32 num_wanted) {
+Kino_MultiTermDocs_bulk_read(TermDocs *term_docs, SV *doc_nums_sv, 
+                             SV *freqs_sv, U32 num_wanted) {
     MultiTermDocsChild *child;
     U32                 i, num_got, base;
     U32                *doc_nums;
@@ -249,7 +247,7 @@ Kino_MultiTermDocs_read(TermDocs *term_docs, SV *doc_nums_sv, SV *freqs_sv,
     child = (MultiTermDocsChild*)term_docs->child;
 
     while (1) {
-		/* move to the next SegTermDocs */
+        /* move to the next SegTermDocs */
         while (child->current == NULL) {
             if (child->pointer < child->num_subs) {
                 child->base = child->starts[ child->pointer ];
@@ -261,15 +259,15 @@ Kino_MultiTermDocs_read(TermDocs *term_docs, SV *doc_nums_sv, SV *freqs_sv,
             }
         }
         
-        num_got = child->current->read(
+        num_got = child->current->bulk_read(
             child->current, doc_nums_sv, freqs_sv, num_wanted );
 
         if (num_got == 0) {
-			/* no more docs left in this segment */
+            /* no more docs left in this segment */
             child->current = NULL;
         }
         else {
-			/* add the start offset for this seg to each doc */
+            /* add the start offset for this seg to each doc */
             base = child->base;
             doc_nums = (U32*)SvPVX(doc_nums_sv);
             for (i = 0; i < num_got; i++) {
@@ -290,14 +288,14 @@ Kino_MultiTermDocs_next(TermDocs* term_docs) {
         return 1;
     }
     else if (child->pointer < child->num_subs) {
-		/* try next segment */
+        /* try next segment */
         child->base    = child->starts[ child->pointer ];
         child->current = child->sub_term_docs[ child->pointer ];
         child->pointer++;
         return term_docs->next(term_docs); /* recurse */
     }
     else {
-		/* done with all segments */
+        /* done with all segments */
         return 0;
     }
 }
@@ -333,7 +331,7 @@ Copyright 2005-2006 Marvin Humphrey
 
 =head1 LICENSE, DISCLAIMER, BUGS, etc.
 
-See L<KinoSearch|KinoSearch> version 0.09.
+See L<KinoSearch|KinoSearch> version 0.10.
 
 =end devdocs
 =cut
