@@ -4,13 +4,14 @@ use warnings;
 use KinoSearch::Util::ToolSet;
 use base qw( KinoSearch::Util::Class );
 
-our %instance_vars = __PACKAGE__->init_instance_vars(
-    # constructor params / members
-    instream => undef,
-    max_doc  => undef,
-    # members
-    bytes => undef,
-);
+BEGIN {
+    __PACKAGE__->init_instance_vars(
+        # constructor params / members
+        instream => undef,
+        max_doc  => undef,
+        bytes    => undef,
+    );
+}
 
 sub init_instance {
     my $self = shift;
@@ -33,6 +34,8 @@ sub _ensure_read {
     }
 }
 
+sub close { shift->{instream}->close }
+
 1;
 
 __END__
@@ -63,7 +66,7 @@ Copyright 2005-2006 Marvin Humphrey
 
 =head1 LICENSE, DISCLAIMER, BUGS, etc.
 
-See L<KinoSearch|KinoSearch> version 0.08.
+See L<KinoSearch|KinoSearch> version 0.10.
 
 =end devdocs
 =cut
