@@ -4,21 +4,21 @@ use warnings;
 use KinoSearch::Util::ToolSet;
 use base qw( KinoSearch::Util::Class );
 
-use File::Temp qw();
-use File::Spec;
+BEGIN {
+    __PACKAGE__->init_instance_vars(
+        #constructor params / members
+        invindex => undef,
+        seg_name => undef,
+
+        # members
+        sort_pool => undef,
+    );
+}
+
 use KinoSearch::Index::TermInfo;
 use KinoSearch::Index::TermInfosWriter;
 use KinoSearch::Util::SortExternal;
 
-our %instance_vars = (
-    # constructor params / members
-    invindex => undef,
-    seg_name => undef,
-
-    # members
-    sort_pool => undef,
-);
-
 sub init_instance {
     my $self = shift;
 
@@ -72,7 +72,10 @@ sub write_postings {
     $tinfos_writer->finish;
 }
 
-sub finish { }
+sub finish {
+    my $self = shift;
+    $self->{sort_pool}->close;
+}
 
 1;
 
@@ -333,7 +336,7 @@ Kino_PostWriter_add_segment(SortExternal *sort_pool, SegTermEnum* term_enum,
         /* start with the termstring and the null byte */
         Kino_encode_bigend_U16(term_buf->text_len, text_len_buf);
         common_len = term_buf->text_len + KINO_FIELD_NUM_LEN;
-        Kino_BB_assign_string(posting, term_buf->termstring, common_len);
+        Kino_BB_assign_string(posting, term_buf->termstring->ptr, common_len);
         Kino_BB_cat_string(posting, "\0", NULL_BYTE_LEN);
         common_len += NULL_BYTE_LEN;
 
@@ -437,7 +440,7 @@ Copyright 2005-2006 Marvin Humphrey
 
 =head1 LICENSE, DISCLAIMER, BUGS, etc.
 
-See L<KinoSearch|KinoSearch> version 0.09.
+See L<KinoSearch|KinoSearch> version 0.10.
 
 =end devdocs
 =cut
