@@ -4,6 +4,35 @@ use warnings;
 use KinoSearch::Util::ToolSet;
 use base qw( KinoSearch::Index::IndexReader );
 
+BEGIN {
+    __PACKAGE__->init_instance_vars(
+        # params/members
+        invindex => undef,
+        seg_name => undef,
+
+        # members
+        comp_file_reader => undef,
+        tinfos_reader    => undef,
+        finfos           => undef,
+        fields_reader    => undef,
+        freq_stream      => undef,
+        prox_stream      => undef,
+        deldocs          => undef,
+        norms_readers    => {},
+    );
+
+    __PACKAGE__->ready_get(
+        qw(
+            finfos
+            fields_reader
+            freq_stream
+            prox_stream
+            deldocs
+            seg_name
+            )
+    );
+}
+
 use KinoSearch::Index::CompoundFileReader;
 use KinoSearch::Index::TermInfosReader;
 use KinoSearch::Index::FieldsReader;
@@ -12,24 +41,6 @@ use KinoSearch::Index::NormsReader;
 use KinoSearch::Index::SegTermDocs;
 use KinoSearch::Index::DelDocs;
 
-our %instance_vars = __PACKAGE__->init_instance_vars(
-    # params/members
-    invindex => undef,
-    seg_name => undef,
-
-    # members
-    comp_file_reader => undef,
-    tinfos_reader    => undef,
-    finfos           => undef,
-    fields_reader    => undef,
-    freq_stream      => undef,
-    prox_stream      => undef,
-    deldocs          => undef,
-    norms_readers    => {},
-);
-
-__PACKAGE__->ready_get(qw( freq_stream prox_stream deldocs ));
-
 # use KinoSearch::Util::Class's new()
 # Note: can't inherit IndexReader's new() without recursion problems
 *new = *KinoSearch::Util::Class::new;
@@ -44,7 +55,7 @@ sub init_instance {
         seg_name => $seg_name,
     );
     $self->{deldocs}->read_deldocs( $invindex, "$seg_name.del" )
-        if ( $self->has_deletions );
+        if ( $invindex->file_exists("$seg_name.del") );
 
     # initialize a CompoundFileReader
     my $comp_file_reader = $self->{comp_file_reader}
@@ -75,17 +86,31 @@ sub init_instance {
     $self->{freq_stream} = $comp_file_reader->open_instream("$seg_name.frq");
     $self->{prox_stream} = $comp_file_reader->open_instream("$seg_name.prx");
     $self->_open_norms;
-
-    # TODO open termvectors
 }
 
 sub max_doc { shift->{fields_reader}->get_size }
 
-sub has_deletions {
+sub num_docs {
     my $self = shift;
-    $self->{invindex}->file_exists("$self->{seg_name}.del");
+    return $self->max_doc - $self->{deldocs}->get_num_deletions;
 }
 
+sub delete_docs_by_term {
+    my ( $self, $term ) = @_;
+    my $term_docs = $self->term_docs($term);
+    $self->{deldocs}->delete_by_term_docs($term_docs);
+}
+
+sub commit_deletions {
+    my $self = shift;
+    return unless $self->{deldocs}->get_num_deletions;
+    my $filename = $self->{seg_name} . ".del";
+    $self->{deldocs}
+        ->write_deldocs( $self->{invindex}, $filename, $self->max_doc );
+}
+
+sub has_deletions { shift->{deldocs}->get_num_deletions }
+
 sub _open_norms {
     my $self = shift;
     my ( $seg_name, $finfos, $comp_file_reader )
@@ -130,6 +155,7 @@ sub term_docs {
 
 sub norms_reader {
     my ( $self, $field_name ) = @_;
+    return unless exists $self->{norms_readers}{$field_name};
     return $self->{norms_readers}{$field_name};
 }
 
@@ -142,10 +168,36 @@ sub get_field_names {
     return \@names;
 }
 
+sub generate_field_infos {
+    my $self       = shift;
+    my $new_finfos = $self->{finfos}->clone;
+    $new_finfos->set_from_file(0);
+    return $new_finfos;
+}
+
 sub fetch_doc {
     $_[0]->{fields_reader}->fetch_doc( $_[1] );
 }
 
+sub segreaders_to_merge {
+    my ( $self, $all ) = @_;
+    return $self if $all;
+    return;
+}
+
+sub close {
+    my $self = shift;
+    return unless $self->{close_invindex};
+
+    $self->{deldocs}->close;
+    $self->{finfos}->close;
+    $self->{fields_reader}->close;
+    $self->{tinfos_reader}->close;
+    $self->{comp_file_reader}->close;
+    $self->{freq_stream}->close;
+    $self->{prox_stream}->close;
+    $_->close for values %{ $self->{norms_readers} };
+}
 1;
 
 __END__
@@ -166,7 +218,7 @@ Copyright 2005-2006 Marvin Humphrey
 
 =head1 LICENSE, DISCLAIMER, BUGS, etc.
 
-See L<KinoSearch|KinoSearch> version 0.08.
+See L<KinoSearch|KinoSearch> version 0.10.
 
 =end devdocs
 =cut
