@@ -4,19 +4,21 @@ use warnings;
 use KinoSearch::Util::ToolSet;
 use base qw( KinoSearch::Util::Class );
 
+BEGIN {
+    __PACKAGE__->init_instance_vars(
+        # constructor params / members
+        invindex => undef,
+        seg_name => undef,
+        finfos   => undef,
+
+        # members
+        orig_enum  => undef,
+        index_enum => undef,
+    );
+}
+
 use KinoSearch::Index::SegTermEnum;
 
-our %instance_vars = __PACKAGE__->init_instance_vars(
-    # constructor params / members
-    invindex => undef,
-    seg_name => undef,
-    finfos   => undef,
-
-    # members
-    orig_enum  => undef,
-    index_enum => undef,
-);
-
 sub init_instance {
     my $self     = shift;
     my $invindex = $self->{invindex};
@@ -54,6 +56,9 @@ sub fetch_term_info {
     my ( $self, $term ) = @_;
     my $termstring = $term->get_termstring( $self->{finfos} );
 
+    # termstring will be undefined if field doesn't exist
+    return unless defined $termstring;
+
     $self->_seek_enum($termstring);
 
     return $self->_scan_enum($termstring);
@@ -128,7 +133,7 @@ Copyright 2005-2006 Marvin Humphrey
 
 =head1 LICENSE, DISCLAIMER, BUGS, etc.
 
-See L<KinoSearch|KinoSearch> version 0.09.
+See L<KinoSearch|KinoSearch> version 0.10.
 
 =end devdocs
 =cut
