@@ -4,18 +4,21 @@ use warnings;
 use KinoSearch::Util::ToolSet;
 use base qw( KinoSearch::Util::Class );
 
-our %instance_vars = __PACKAGE__->init_instance_vars(
-    # constructor params
-    invindex       => undef,
-    seg_name       => undef,
-    is_index       => 0,
-    index_interval => 1024,
-    skip_interval  => 16,
-);
+BEGIN {
+    __PACKAGE__->init_instance_vars(
+        # constructor params
+        invindex       => undef,
+        seg_name       => undef,
+        is_index       => 0,
+        index_interval => 1024,
+        skip_interval  => 16,
+    );
+}
+our %instance_vars;
 
 sub new {
     my $class = shift;
-    verify_args( \%instance_vars, @_ );
+    confess kerror() unless verify_args( \%instance_vars, @_ );
     my %args = ( %instance_vars, @_ );
 
     # open an outstream
@@ -118,11 +121,7 @@ ALIAS:
     _get_size      = 8
 CODE:
 {
-     /* if called as a setter, make sure the extra arg is there */
-    if (ix % 2 == 1 && items != 2)
-        Kino_confess("usage: $term_info->set_xxxxxx($val)");
-
-    switch (ix) {
+    KINO_START_SET_OR_GET_SWITCH
 
     case 1:  SvREFCNT_dec(obj->other_sv);
              obj->other_sv = newSVsv( ST(1) );
@@ -140,7 +139,8 @@ CODE:
 
     case 8:  RETVAL = newSViv(obj->size);
              break;
-    }
+
+    KINO_END_SET_OR_GET_SWITCH
 }
 OUTPUT: RETVAL
 
@@ -344,7 +344,7 @@ Copyright 2005-2006 Marvin Humphrey
 
 =head1 LICENSE, DISCLAIMER, BUGS, etc.
 
-See L<KinoSearch|KinoSearch> version 0.09.
+See L<KinoSearch|KinoSearch> version 0.10.
 
 =end devdocs
 =cut
