@@ -4,10 +4,12 @@ use warnings;
 use KinoSearch::Util::ToolSet;
 use base qw( KinoSearch::Util::Class );
 
-our %instance_vars = __PACKAGE__->init_instance_vars(
-    occur => 'SHOULD',
-    query => undef,
-);
+BEGIN {
+    __PACKAGE__->init_instance_vars(
+        occur => 'SHOULD',
+        query => undef,
+    );
+}
 
 sub init_instance {
     my $self = shift;
@@ -54,7 +56,7 @@ Copyright 2005-2006 Marvin Humphrey
 
 =head1 LICENSE, DISCLAIMER, BUGS, etc.
 
-See L<KinoSearch|KinoSearch> version 0.08.
+See L<KinoSearch|KinoSearch> version 0.10.
 
 =end devdocs
 =cut
