@@ -4,13 +4,14 @@ use warnings;
 use KinoSearch::Util::ToolSet;
 use base qw( KinoSearch::Util::Class );
 
-our %instance_vars = __PACKAGE__->init_instance_vars(
-    doc_num => undef,
-    score   => undef,
-    doc     => undef,
-);
-
-__PACKAGE__->ready_get_set(qw( doc_num score doc ));
+BEGIN {
+    __PACKAGE__->init_instance_vars(
+        doc_num => undef,
+        score   => undef,
+        doc     => undef,
+    );
+    __PACKAGE__->ready_get_set(qw( doc_num score doc ));
+}
 
 1;
 
@@ -32,7 +33,7 @@ Copyright 2005-2006 Marvin Humphrey
 
 =head1 LICENSE, DISCLAIMER, BUGS, etc.
 
-See L<KinoSearch|KinoSearch> version 0.08.
+See L<KinoSearch|KinoSearch> version 0.10.
 
 =end devdocs
 
