@@ -4,9 +4,9 @@ use warnings;
 use KinoSearch::Util::ToolSet;
 use base qw( KinoSearch::Util::PriorityQueue );
 
-use KinoSearch::Search::HitDoc;
+BEGIN { __PACKAGE__->init_instance_vars() }
 
-our %instance_vars = __PACKAGE__->init_instance_vars();
+use KinoSearch::Search::HitDoc;
 
 sub new {
     my $either = shift;
@@ -104,7 +104,7 @@ Copyright 2005-2006 Marvin Humphrey
 
 =head1 LICENSE, DISCLAIMER, BUGS, etc.
 
-See L<KinoSearch|KinoSearch> version 0.09.
+See L<KinoSearch|KinoSearch> version 0.10.
 
 =end devdocs
 =cut
