@@ -4,26 +4,28 @@ use warnings;
 use KinoSearch::Util::ToolSet;
 use base qw( KinoSearch::Util::Class );
 
+BEGIN {
+    __PACKAGE__->init_instance_vars(
+        # params/members
+        searcher  => undef,
+        query     => undef,
+        filter    => undef,
+        sort_spec => undef,
+        num_docs  => undef,
+
+        # members
+        weight      => undef,
+        hit_queue   => undef,
+        highlighter => undef,
+
+        hit_docs   => undef,
+        pointer    => undef,
+        total_hits => undef,
+    );
+}
+
 use KinoSearch::Highlight::Highlighter;
-
-our %instance_vars = __PACKAGE__->init_instance_vars(
-    # params/members
-    searcher  => undef,
-    query     => undef,
-    filter    => undef,
-    sort_spec => undef,
-    num_docs  => undef,
-
-    # members
-    weight      => undef,
-    hit_queue   => undef,
-    highlighter => undef,
-
-    hit_docs   => undef,
-    pointer    => undef,
-    total_hits => undef,
-
-);
+use KinoSearch::Search::HitCollector;
 
 sub init_instance {
     my $self = shift;
@@ -44,16 +46,18 @@ sub seek {
     $self->{pointer} = $start_offset;
 
     # collect enough to satisfy both the offset and the num wanted
-    $num_wanted += $start_offset;
+    my $collector = KinoSearch::Search::HitQueueCollector->new(
+        size => $num_wanted + $start_offset, );
 
     # execute the search!
-    @{$self}{qw( hit_queue total_hits )}
-        = $self->{searcher}->search_hit_queue(
-        num_wanted => $num_wanted,
-        weight     => $self->{weight},
-        filter     => $self->{filter},
-        sort_spec  => $self->{sort_spec},
-        );
+    $self->{searcher}->search_hit_collector(
+        hit_collector => $collector,
+        weight        => $self->{weight},
+        filter        => $self->{filter},
+        sort_spec     => $self->{sort_spec},
+    );
+    $self->{total_hits} = $collector->get_total_hits;
+    $self->{hit_queue}  = $collector->get_hit_queue;
 
     # turn the HitQueue into HitDocs
     $self->{hit_docs} = $self->{hit_queue}->hit_docs;
@@ -61,14 +65,14 @@ sub seek {
 
 sub total_hits {
     my $self = shift;
-    croak("must seek before calling total_hits")
+    $self->seek( 0, 100 )
         unless defined $self->{total_hits};
     return $self->{total_hits};
 }
 
 sub fetch_hit_hashref {
     my $self = shift;
-    croak("must seek before calling fetch_hit_hashref")
+    $self->seek( 0, 100 )
         unless defined $self->{total_hits};
 
     # bail if there aren't any more *captured* hits
@@ -95,7 +99,7 @@ my %create_excerpts_defaults = ( highlighter => undef, );
 
 sub create_excerpts {
     my $self = shift;
-    verify_args( \%create_excerpts_defaults, @_ );
+    confess kerror() unless verify_args( \%create_excerpts_defaults, @_ );
     my %args = ( %create_excerpts_defaults, @_ );
 
     $self->{highlighter} = $args{highlighter};
@@ -118,7 +122,9 @@ KinoSearch::Search::Hits - access search results
 
 =head1 DESCRIPTION
 
-Hits objects are used to access the results of a search.  
+Hits objects are used to access the results of a search.  By default, a hits
+object provides access to the top 100 matches; the seek() method provides
+finer-grained control.
 
 A classic application would be paging through hits.  The first time, seek to a
 START of 0, and retrieve 10 documents.  If the user wants to see more -- and
@@ -168,7 +174,7 @@ Copyright 2005-2006 Marvin Humphrey
 
 =head1 LICENSE, DISCLAIMER, BUGS, etc.
 
-See L<KinoSearch|KinoSearch> version 0.08.
+See L<KinoSearch|KinoSearch> version 0.10.
 
 =cut
 
