@@ -4,21 +4,23 @@ use warnings;
 use KinoSearch::Util::ToolSet;
 use base qw( KinoSearch::Search::Query );
 
+BEGIN {
+    __PACKAGE__->init_instance_vars(
+        # constructor args / members
+        slop => 0,
+        # members
+        field     => undef,
+        terms     => [],
+        positions => [],
+    );
+    __PACKAGE__->ready_get_set(qw( slop ));
+    __PACKAGE__->ready_get(qw( terms ));
+}
+
 use KinoSearch::Search::TermQuery;
 use KinoSearch::Document::Field;
 use KinoSearch::Util::ToStringUtils qw( boost_to_string );
 
-our %instance_vars = __PACKAGE__->init_instance_vars(
-    # constructor args / members
-    slop => 0,
-    # members
-    field     => undef,
-    terms     => [],
-    positions => [],
-);
-__PACKAGE__->ready_get_set(qw( slop ));
-__PACKAGE__->ready_get(qw( terms ));
-
 # Add a term/position combo to the query.  The position is specified
 # explicitly in order to allow for phrases with gaps, two terms at the same
 # position, etc.
@@ -77,9 +79,9 @@ use warnings;
 use KinoSearch::Util::ToolSet;
 use base qw( KinoSearch::Search::Weight );
 
-use KinoSearch::Search::PhraseScorer;
+BEGIN { __PACKAGE__->init_instance_vars(); }
 
-our %instance_vars = __PACKAGE__->init_instance_vars();
+use KinoSearch::Search::PhraseScorer;
 
 sub init_instance {
     my $self = shift;
@@ -163,7 +165,7 @@ Copyright 2005-2006 Marvin Humphrey
 
 =head1 LICENSE, DISCLAIMER, BUGS, etc.
 
-See L<KinoSearch|KinoSearch> version 0.09.
+See L<KinoSearch|KinoSearch> version 0.10.
 
 =cut
 
