@@ -4,18 +4,21 @@ use warnings;
 use KinoSearch::Util::ToolSet;
 use base qw( KinoSearch::Search::Scorer );
 
-our %instance_vars = __PACKAGE__->init_instance_vars(
-    # constructor params
-    weight         => undef,
-    term_docs      => [],
-    phrase_offsets => [],
-    norms_reader   => undef,
-    slop           => 0,
-);
+BEGIN {
+    __PACKAGE__->init_instance_vars(
+        # constructor params
+        weight         => undef,
+        term_docs      => [],
+        phrase_offsets => [],
+        norms_reader   => undef,
+        slop           => 0,
+    );
+}
+our %instance_vars;
 
 sub new {
     my $self = shift->SUPER::new;
-    verify_args( \%instance_vars, @_ );
+    confess kerror() unless verify_args( \%instance_vars, @_ );
     my %args = ( %instance_vars, @_ );
 
     $self->_init_child;
@@ -90,8 +93,6 @@ PPCODE:
 SV*
 _phrase_scorer_set_or_get(scorer, ...)
     Scorer *scorer;
-PREINIT:
-    PhraseScorerChild *child;
 ALIAS:
     _set_slop = 1
     _get_slop = 2
@@ -101,13 +102,9 @@ ALIAS:
     _get_norms        = 6
 CODE:
 {
-    child = (PhraseScorerChild*)scorer->child;
+    PhraseScorerChild *child = (PhraseScorerChild*)scorer->child;
 
-    /* if called as a setter, make sure the extra arg is there */
-    if (ix % 2 == 1 && items != 2)
-        Kino_confess("usage: $scorer->set_xxxxxx($val)");
-
-    switch (ix) {
+    KINO_START_SET_OR_GET_SWITCH
 
     case 1:  child->slop = SvIV( ST(1) );
              /* fall through */
@@ -135,7 +132,7 @@ CODE:
     case 6:  RETVAL = newSVsv(child->norms_sv);
              break;
 
-    }
+    KINO_END_SET_OR_GET_SWITCH
 }
 OUTPUT: RETVAL
 
@@ -404,7 +401,7 @@ Copyright 2005-2006 Marvin Humphrey
 
 =head1 LICENSE, DISCLAIMER, BUGS, etc.
 
-See L<KinoSearch|KinoSearch> version 0.09.
+See L<KinoSearch|KinoSearch> version 0.10.
 
 =end devdocs
 =cut
