@@ -1,52 +1,45 @@
+package KinoSearch::Search::QueryFilter;
 use strict;
 use warnings;
-
-package KinoSearch::Search::QueryFilter;
 use KinoSearch::Util::ToolSet;
-use base qw( KinoSearch::Search::Filter );
+use base qw( KinoSearch::Util::Class );
 
-our %instance_vars = (
-    # inherited
-    cached_bits => undef,
-
-    # constructor params / members
-    query => undef,
-);
+BEGIN {
+    __PACKAGE__->init_instance_vars(
+        # constructor params / members
+        query => undef,
+        # members
+        cached_bits => undef,
+    );
+}
 
 use KinoSearch::Search::HitCollector;
-use KinoSearch::Util::BitVector;
 
 sub init_instance {
     my $self = shift;
     confess("required parameter query is not a KinoSearch::Search::Query")
         unless a_isa_b( $self->{query}, 'KinoSearch::Search::Query' );
-    $self->{cached_bits} = {};
 }
 
 sub bits {
-    my ( $self, $reader ) = @_;
-
-    my $cached_bits = $self->fetch_cached_bits($reader);
+    my ( $self, $searcher ) = @_;
 
     # fill the cache
-    if ( !defined $cached_bits ) {
-        $cached_bits = KinoSearch::Util::BitVector->new(
-            capacity => $reader->max_doc );
-        $self->store_cached_bits( $reader, $cached_bits );
-
-        my $collector = KinoSearch::Search::HitCollector->new_bit_coll(
-            bit_vector => $cached_bits );
-
-        my $searcher = KinoSearch::Searcher->new( reader => $reader );
+    if ( !defined $self->{cache} ) {
+        my $collector = KinoSearch::Search::BitCollector->new(
+            capacity => $searcher->max_doc, );
 
         # perform the search
-        $searcher->collect(
-            query     => $self->{query},
-            collector => $collector,
+        $searcher->search_hit_collector(
+            weight        => $self->{query}->to_weight($searcher),
+            hit_collector => $collector,
         );
+
+        # save the bitvector of doc hits
+        $self->{cached_bits} = $collector->get_bit_vector;
     }
 
-    return $cached_bits;
+    return $self->{cached_bits};
 }
 
 1;
@@ -55,12 +48,12 @@ __END__
 
 =head1 NAME
 
-KinoSearch::Search::QueryFilter - Build a filter based on results of a query.
+KinoSearch::Search::QueryFilter - build a filter based on results of a query
 
 =head1 SYNOPSIS
 
     my $books_only_query  = KinoSearch::Search::TermQuery->new(
-        term => KinoSearch::Index::Term->new( 'category', 'books' ),
+        term => KinoSearch::Index::Term->new( 'category', 'books' );
     );
     my $filter = KinoSearch::Search::QueryFilter->new(
         query => $books_only_query;
@@ -85,15 +78,16 @@ caches its results, so it is more efficient if you use it more than once.
         query => $query;
     );
 
-Constructor.  Takes one hash-style parameter, C<query>, which must be an object
-belonging to a subclass of L<KinoSearch::Search::Query>.
+Constructor.  Takes one hash-style parameter, C<query>, which must be an
+object belonging to a subclass of
+L<KinoSearch::Search::Query|KinoSearch::Search::Query>.
 
 =head1 COPYRIGHT
 
-Copyright 2005-2007 Marvin Humphrey
+Copyright 2005-2006 Marvin Humphrey
 
 =head1 LICENSE, DISCLAIMER, BUGS, etc.
 
-See L<KinoSearch> version 0.20.
+See L<KinoSearch|KinoSearch> version 0.10.
 
 =cut
