@@ -3,12 +3,16 @@ use strict;
 use warnings;
 use KinoSearch::Util::ToolSet;
 use base qw( KinoSearch::Util::CClass Exporter );
-our @EXPORT_OK = qw( %score_batch_args );
 
-our %instance_vars = __PACKAGE__->init_instance_vars(
-    # constructor params
-    similarity => undef,
-);
+BEGIN {
+    __PACKAGE__->init_instance_vars(
+        # constructor params
+        similarity => undef,
+    );
+}
+our %instance_vars;
+
+our @EXPORT_OK = qw( %score_batch_args );
 
 sub new {
     my $class = shift;
@@ -69,11 +73,7 @@ ALIAS:
     get_similarity = 2
 CODE:
 {
-    /* if called as a setter, make sure the extra arg is there */
-    if (ix % 2 == 1 && items != 2)
-        croak("usage: $term_info->set_xxxxxx($val)");
-
-    switch (ix) {
+    KINO_START_SET_OR_GET_SWITCH
 
     case 1:  SvREFCNT_dec(scorer->similarity_sv);
              scorer->similarity_sv = newSVsv( ST(1) );
@@ -82,7 +82,8 @@ CODE:
              /* fall through */
     case 2:  RETVAL = newSVsv(scorer->similarity_sv);
              break;
-    }
+
+    KINO_END_SET_OR_GET_SWITCH
 }
 OUTPUT: RETVAL
 
@@ -285,7 +286,7 @@ Copyright 2005-2006 Marvin Humphrey
 
 =head1 LICENSE, DISCLAIMER, BUGS, etc.
 
-See L<KinoSearch|KinoSearch> version 0.09.
+See L<KinoSearch|KinoSearch> version 0.10.
 
 =end devdocs
 =cut
