@@ -4,12 +4,16 @@ use warnings;
 use KinoSearch::Util::ToolSet;
 use base qw( KinoSearch::Util::Class );
 
+BEGIN {
+    __PACKAGE__->init_instance_vars(
+        # members
+        similarity => undef
+    );
+    __PACKAGE__->ready_get_set(qw( similarity ));
+}
+
 use KinoSearch::Search::Similarity;
 
-our %instance_vars = __PACKAGE__->init_instance_vars( similarity => undef );
-
-__PACKAGE__->ready_get_set(qw( similarity ));
-
 =begin comment
 
     my $hits = $searchable->search($query_string);
@@ -101,7 +105,7 @@ Copyright 2005-2006 Marvin Humphrey
 
 =head1 LICENSE, DISCLAIMER, BUGS, etc.
 
-See L<KinoSearch|KinoSearch> version 0.08.
+See L<KinoSearch|KinoSearch> version 0.10.
 
 =end devdocs
 =cut
