@@ -4,7 +4,7 @@ use warnings;
 use KinoSearch::Util::ToolSet;
 use base qw( KinoSearch::Util::CClass );
 
-our %instance_vars = __PACKAGE__->init_instance_vars();
+BEGIN { __PACKAGE__->init_instance_vars(); }
 
 # See _float_to_byte.
 *encode_norm = *_float_to_byte;
@@ -301,7 +301,7 @@ Copyright 2005-2006 Marvin Humphrey
 
 =head1 LICENSE, DISCLAIMER, BUGS, etc.
 
-See L<KinoSearch|KinoSearch> version 0.09.
+See L<KinoSearch|KinoSearch> version 0.10.
 
 =end devdocs
 =cut
