@@ -6,7 +6,13 @@ use base qw( KinoSearch::Search::Query );
 
 use KinoSearch::Util::ToStringUtils qw( boost_to_string );
 
-our %instance_vars = __PACKAGE__->init_instance_vars( term => undef );
+BEGIN {
+    __PACKAGE__->init_instance_vars(
+        # constructor params / members
+        term => undef,
+    );
+    __PACKAGE__->ready_get(qw( term ));
+}
 
 sub init_instance {
     my $self = shift;
@@ -14,8 +20,6 @@ sub init_instance {
         unless a_isa_b( $self->{term}, 'KinoSearch::Index::Term' );
 }
 
-sub get_term { shift->{term} }
-
 sub create_weight {
     my ( $self, $searcher ) = @_;
     my $weight = KinoSearch::Search::TermWeight->new(
@@ -62,6 +66,7 @@ sub scorer {
     my $term      = $self->{parent}{term};
     my $term_docs = $reader->term_docs($term);
     return unless defined $term_docs;
+    return unless $term_docs->get_doc_freq;
 
     my $norms_reader = $reader->norms_reader( $term->get_field );
     return KinoSearch::Search::TermScorer->new(
@@ -124,7 +129,7 @@ Copyright 2005-2006 Marvin Humphrey
 
 =head1 LICENSE, DISCLAIMER, BUGS, etc.
 
-See L<KinoSearch|KinoSearch> version 0.08.
+See L<KinoSearch|KinoSearch> version 0.10.
 
 =cut
 
