@@ -4,14 +4,14 @@ use warnings;
 use KinoSearch::Util::ToolSet;
 use base qw( KinoSearch::Store::Lock );
 
+BEGIN { __PACKAGE__->init_instance_vars() }
+
 use Fcntl qw( :DEFAULT :flock );
 use File::Spec::Functions qw( catfile );
 use KinoSearch::Store::FSInvIndex;
 
 my $disable_locks = 0;    # placeholder -- locks always enabled for now
 
-our %instance_vars = __PACKAGE__->init_instance_vars();
-
 sub init_instance {
     my $self = shift;
 
@@ -71,7 +71,7 @@ Copyright 2005-2006 Marvin Humphrey
 
 =head1 LICENSE, DISCLAIMER, BUGS, etc.
 
-See L<KinoSearch|KinoSearch> version 0.09.
+See L<KinoSearch|KinoSearch> version 0.10.
 
 =end devdocs
 =cut
