@@ -131,11 +131,7 @@ ALIAS:
     get_fh       = 6
 CODE:
 {
-     /* if called as a setter, make sure the extra arg is there */
-    if (ix % 2 == 1 && items != 2)
-        Kino_confess("usage: $term_info->set_xxxxxx($val)");
-
-    switch (ix) {
+    KINO_START_SET_OR_GET_SWITCH
 
     case 1:  instream->len = SvNV( ST(1) );
              /* fall through */
@@ -151,7 +147,8 @@ CODE:
              /* fall through */
     case 6:  RETVAL = newSVsv(instream->fh_sv);
              break;
-    }
+
+    KINO_END_SET_OR_GET_SWITCH
 }
 OUTPUT: RETVAL
 
@@ -330,7 +327,7 @@ typedef struct instream {
     double (*read_vlong)(struct instream*);
 } InStream;
 
-InStream* Kino_InStream_new     (char*, SV*, U32, double);
+InStream* Kino_InStream_new     (char*, SV*, double, double);
 void   Kino_InStream_seek       (InStream*, double);
 double Kino_InStream_tell       (InStream*);
 void   Kino_InStream_refill     (InStream*);
@@ -352,7 +349,7 @@ __C__
 
 
 InStream*
-Kino_InStream_new(char *class, SV *fh_sv, U32 offset, double len ) {
+Kino_InStream_new(char *class, SV *fh_sv, double offset, double len ) {
     InStream *instream;
 
     /* allocate */
@@ -616,7 +613,7 @@ Copyright 2005-2006 Marvin Humphrey
 
 =head1 LICENSE, DISCLAIMER, BUGS, etc.
 
-See L<KinoSearch|KinoSearch> version 0.09.
+See L<KinoSearch|KinoSearch> version 0.10.
 
 =end devdocs
 =cut
