@@ -4,7 +4,7 @@ use warnings;
 use KinoSearch::Util::ToolSet;
 use base qw( KinoSearch::Store::Lock );
 
-our %instance_vars = __PACKAGE__->init_instance_vars;
+BEGIN { __PACKAGE__->init_instance_vars() }
 
 sub do_obtain {
     my $self = shift;
@@ -50,7 +50,7 @@ Copyright 2005-2006 Marvin Humphrey
 
 =head1 LICENSE, DISCLAIMER, BUGS, etc.
 
-See L<KinoSearch|KinoSearch> version 0.08.
+See L<KinoSearch|KinoSearch> version 0.10.
 
 =end devdocs
 =cut
