@@ -4,7 +4,12 @@ use warnings;
 use KinoSearch::Util::ToolSet;
 use base qw( KinoSearch::Util::CClass );
 
-our %instance_vars = __PACKAGE__->init_instance_vars( capacity => 0, );
+BEGIN {
+    __PACKAGE__->init_instance_vars(
+        # constructor params
+        capacity => 0,
+    );
+}
 
 1;
 
@@ -188,11 +193,7 @@ PREINIT:
     char   *new_bits;
 CODE:
 {
-    /* if called as a setter, make sure the extra arg is there */
-    if (ix % 2 == 1 && items != 2)
-        croak("usage: $term_info->set_xxxxxx($val)");
-
-    switch (ix) {
+    KINO_START_SET_OR_GET_SWITCH
 
     case 1:  new_capacity = SvUV(ST(1));
              if (new_capacity < bit_vec->capacity) {
@@ -214,8 +215,7 @@ CODE:
              RETVAL = newSVpv((char*)bit_vec->bits, len);
              break;
 
-    default: Kino_confess("Internal error: _set_or_get ix: %d", ix); 
-    }
+    KINO_END_SET_OR_GET_SWITCH
 }
 OUTPUT: RETVAL
 
@@ -561,7 +561,7 @@ Copyright 2005-2006 Marvin Humphrey
 
 =head1 LICENSE, DISCLAIMER, BUGS, etc.
 
-See L<KinoSearch|KinoSearch> version 0.09.
+See L<KinoSearch|KinoSearch> version 0.10.
 
 =end devdocs
 =cut
