@@ -4,10 +4,12 @@ use warnings;
 use KinoSearch::Util::ToolSet;
 use base qw( KinoSearch::Util::CClass );
 
-our %instance_vars = __PACKAGE__->init_instance_vars(
-    # constructor args
-    max_size => undef,
-);
+BEGIN {
+    __PACKAGE__->init_instance_vars(
+        # constructor args
+        max_size => undef,
+    );
+}
 
 1;
 
@@ -123,15 +125,15 @@ ALIAS:
     get_max_size  = 4
 CODE:
 {
-    switch (ix) {
+    KINO_START_SET_OR_GET_SWITCH
+
     case 2:  RETVAL = newSVuv(pq->size);
              break;
 
     case 4:  RETVAL = newSVuv(pq->max_size);
              break;
 
-    default: Kino_confess("Internal error: _set_or_get ix: %d", ix); 
-    }
+    KINO_END_SET_OR_GET_SWITCH
 }
 OUTPUT: RETVAL
 
@@ -456,7 +458,7 @@ Copyright 2005-2006 Marvin Humphrey
 
 =head1 LICENSE, DISCLAIMER, BUGS, etc.
 
-See L<KinoSearch|KinoSearch> version 0.09.
+See L<KinoSearch|KinoSearch> version 0.10.
 
 =end devdocs
 =cut
