@@ -4,12 +4,15 @@ use warnings;
 use KinoSearch::Util::ToolSet;
 use base qw( KinoSearch::Util::CClass );
 
-our %instance_vars = __PACKAGE__->init_instance_vars(
-    # constructor args
-    invindex      => undef,
-    seg_name      => undef,
-    mem_threshold => 2**24,
-);
+BEGIN {
+    __PACKAGE__->init_instance_vars(
+        # constructor args
+        invindex      => undef,
+        seg_name      => undef,
+        mem_threshold => 2**24,
+    );
+}
+our %instance_vars;
 
 sub new {
     my $class = shift;
@@ -49,6 +52,8 @@ sub sort_all {
     $self->_enable_fetch;
 }
 
+sub close { shift->_get_instream()->close }
+
 1;
 
 __END__
@@ -167,11 +172,7 @@ ALIAS:
     _get_seg_name  = 10
 CODE:
 {
-    /* if called as a setter, make sure the extra arg is there */
-    if (ix % 2 == 1 && items != 2)
-        croak("usage: $term_info->set_xxxxxx($val)");
-    
-    switch (ix) {
+    KINO_START_SET_OR_GET_SWITCH
 
     case 1:  SvREFCNT_dec(sortex->outstream_sv);
              sortex->outstream_sv = newSVsv( ST(1) );
@@ -203,7 +204,8 @@ CODE:
              /* fall through */
     case 10: RETVAL = newSVsv(sortex->seg_name_sv);
              break;
-    }
+
+    KINO_END_SET_OR_GET_SWITCH
 }
 OUTPUT: RETVAL
 
@@ -689,9 +691,9 @@ Kino_SortEx_define_slice(SortExRun *run, ByteBuf *endpost) {
         mid = (lo + hi) / 2;
         delta = Kino_BB_compare(cache[mid], endpost);
         if (delta > 0) 
-			hi = mid;
+            hi = mid;
         else
-			lo = mid;
+            lo = mid;
     }
 
     run->slice_size = lo == -1 
@@ -831,7 +833,7 @@ Copyright 2005-2006 Marvin Humphrey
 
 =head1 LICENSE, DISCLAIMER, BUGS, etc.
 
-See L<KinoSearch|KinoSearch> version 0.09.
+See L<KinoSearch|KinoSearch> version 0.10.
 
 =end devdocs
 =cut
